@echo off

rem #  ------------------------------------------------------------
rem #  Company: Software- und Organisations-Service GmbH
rem #  Purpose: Start script for JS7 Converter
rem #  ------------------------------------------------------------

SETLOCAL

rem ### SETTINGS ##############################################

rem # This variable has to point to the location of 
rem # the JS7 Converteer.
rem # If this variable is not defined then the parent directory 
rem # of this start script is used.
  
rem set JS7_CONVERTER_HOME=

rem ###########################################################


rem ##########################
rem # set and check home
set JS7_CONVERTER_START_SCRIPT=%~dpnx0
if not defined JS7_CONVERTER_HOME set JS7_CONVERTER_HOME=%~dp0
call :normalize_home "%JS7_CONVERTER_HOME%\dummy"
if not exist "%JS7_CONVERTER_HOME%\lib" (
  echo ...the directory "%JS7_CONVERTER_HOME%\lib" is missing!
  echo did you move the start script?
  echo please set the JS7_CONVERTER_HOME variable.
  call :more_info
  exit /b 3
)

rem ##########################
rem # set default values
set JS7_CONVERTER_DEFAULT_OUTPUT_DIR=%JS7_CONVERTER_HOME%\output
set JS7_CONVERTER_DEFAULT_REPORT_DIR=%JS7_CONVERTER_HOME%\report
set JS7_CONVERTER_DEFAULT_ARCHIVE=%JS7_CONVERTER_HOME%\js7_converted_js1.zip
set JS7_CONVERTER_DEFAULT_CONFIG=%JS7_CONVERTER_HOME%\js7_convert_js1.config

rem ##########################
rem # read command line options
if "%~1" == "" goto usage
:read_command_line_options
set OPTION_VALUE=%~1
set OPTION_VALUE=%OPTION_VALUE:--input-dir=%
set OPTION_VALUE=%OPTION_VALUE:--output-dir=%
set OPTION_VALUE=%OPTION_VALUE:--report-dir=%
set OPTION_VALUE=%OPTION_VALUE:--archive=%
set OPTION_VALUE=%OPTION_VALUE:--config=%
set OPTION_VALUE=%OPTION_VALUE:--help=%
set OPTION_VALUE=%OPTION_VALUE:"=%

if "%~1" == "" goto read_command_line_options_end
if "%~1" == "--input-dir" (
  if "%OPTION_VALUE%" == "" goto read_command_line_options
  set JS7_CONVERTER_INPUT_DIR=%~2
)
if "%~1" == "--output-dir" (
  if "%OPTION_VALUE%" == "" goto read_command_line_options
  set JS7_CONVERTER_OUTPUT_DIR=%~2
)
if "%~1" == "--report-dir" (
  if "%OPTION_VALUE%" == "" goto read_command_line_options
  set JS7_CONVERTER_REPORT_DIR=%~2
)
if "%~1" == "--archive" (
  if "%OPTION_VALUE%" == "" goto read_command_line_options
  set JS7_CONVERTER_ARCHIVE=%~2
)
if "%~1" == "--config" (
  if "%OPTION_VALUE%" == "" goto read_command_line_options
  set JS7_CONVERTER_CONFIG=%~2
)
if "%~1" == "--help" (
  if "%OPTION_VALUE%" == "" goto usage
)
shift
goto read_command_line_options
:read_command_line_options_end


rem ##########################
rem # set environment and create directories

if not defined JS7_CONVERTER_INPUT_DIR (
  echo ...option --input-dir is missing
  echo ...please specify the --input-dir=^<directory^> option with an existing directory for JS1 scheduling *.xml files
  call :more_info
  exit /b %ERRORLEVEL%
)
if not exist "%JS7_CONVERTER_INPUT_DIR%" (
  echo ...could not find input directory: %JS7_CONVERTER_INPUT_DIR%
  echo ...please specify the --input-dir=^<directory^> option with an existing directory for JS1 scheduling *.xml files
  call :more_info
  exit /b %ERRORLEVEL%
)

if not defined JS7_CONVERTER_CONFIG set JS7_CONVERTER_CONFIG=%JS7_CONVERTER_DEFAULT_CONFIG%
if not exist "%JS7_CONVERTER_CONFIG%" (
  echo ...could not find configuration file: %JS7_CONVERTER_CONFIG%
  echo ...please specify the --config=^<file^> option with an existing configuration file
  call :more_info
  exit /b %ERRORLEVEL%
)

if not defined JS7_CONVERTER_OUTPUT_DIR set JS7_CONVERTER_OUTPUT_DIR=%JS7_CONVERTER_DEFAULT_OUTPUT_DIR%
if not exist "%JS7_CONVERTER_OUTPUT_DIR%" mkdir "%JS7_CONVERTER_OUTPUT_DIR%"
if ERRORLEVEL 1 (
  echo ...could not create output directory: %JS7_CONVERTER_OUTPUT_DIR%
  echo ...please check permissions
  call :more_info
  exit /b %ERRORLEVEL%
)

if not defined JS7_CONVERTER_REPORT_DIR set JS7_CONVERTER_REPORT_DIR=%JS7_CONVERTER_DEFAULT_REPORT_DIR%
if not exist "%JS7_CONVERTER_REPORT_DIR%" mkdir "%JS7_CONVERTER_REPORT_DIR%"
if ERRORLEVEL 1 (
  echo ...could not create report directory: %JS7_CONVERTER_REPORT_DIR%
  echo ...please check permissions
  call :more_info
  exit /b %ERRORLEVEL%
)

if not defined JS7_CONVERTER_ARCHIVE set JS7_CONVERTER_ARCHIVE=%JS7_CONVERTER_DEFAULT_ARCHIVE%


rem ##########################
rem # set and check java
set JAVABIN=java.exe
if exist "%JAVA_HOME%\bin\java.exe" set JAVABIN=%JAVA_HOME%\bin\java.exe


rem ##########################
rem # ... and action
:action
goto command


:usage
echo Usage: %JS7_CONVERTER_START_SCRIPT% [options]
echo   options:
echo     --input-dir=^<location of input directory^>                       ^| required argument
echo     --output-dir=^<location of output directory^>                     ^| default: %JS7_CONVERTER_DEFAULT_OUTPUT_DIR%
echo     --report-dir=^<location of report directory^>                     ^| default: %JS7_CONVERTER_DEFAULT_REPORT_DIR%
echo     --archive=^<location of resulting .zip archive for JS7 import^>   ^| default: %JS7_CONVERTER_DEFAULT_ARCHIVE%
echo     --config=^<location of config file^>                              ^| default: %JS7_CONVERTER_DEFAULT_CONFIG%
echo     --help
call :more_info
exit /b 0


:more_info
echo ...see https://kb.sos-berlin.com/x/l8bAAw for more information.
goto final


:command
call :normalize_input_dir "%JS7_CONVERTER_INPUT_DIR%\dummy"
set JS7_CONVERTER_LIBDIR=%JS7_CONVERTER_HOME:\=/%/lib

if not defined JS7_CONVERTER_TZ (
  if exist "%JS7_CONVERTER_HOME%\lib\classes\DefaultTimeZone.class" (
    for /f "usebackq" %%i in (`java -classpath "%JS7_CONVERTER_LIBDIR%/classes" DefaultTimeZone 2^>nul`) do set JS7_CONVERTER_TZ=%%i
  )
)
if not defined JS7_CONVERTER_TZ set JS7_CONVERTER_TZ=Etc/UTC

call "%JAVABIN%" -Xmx256m -classpath "%JS7_CONVERTER_LIBDIR%/sos/*;%JS7_CONVERTER_LIBDIR%/3rd-party/*;%JS7_CONVERTER_LIBDIR%/3rd-party/compress/*;%JS7_CONVERTER_LIBDIR%/3rd-party/log/*;%JS7_CONVERTER_LIBDIR%/3rd-party/json/*;%JS7_CONVERTER_LIBDIR%/3rd-party/csv/*;%JS7_CONVERTER_LIBDIR%" ^
  com.sos.js7.converter.js1.JS12JS7ConverterMain --input="%JS7_CONVERTER_INPUT_DIR:\=/%" --output-dir="%JS7_CONVERTER_OUTPUT_DIR:\=/%" --report-dir="%JS7_CONVERTER_REPORT_DIR:\=/%" --archive="%JS7_CONVERTER_DEFAULT_ARCHIVE%" --config="%JS7_CONVERTER_CONFIG:\=/%" %*
exit /b %ERRORLEVEL%
goto final


:normalize_home
set JS7_CONVERTER_HOME=%~dp1
set JS7_CONVERTER_HOME=%JS7_CONVERTER_HOME:~0,-1%
goto final


:normalize_input_dir
set JS7_CONVERTER_INPUT_DIR=%~dp1
set JS7_CONVERTER_INPUT_DIR=%JS7_CONVERTER_INPUT_DIR:~0,-1%
goto final


:finally
exit /b %ERRORLEVEL%

ENDLOCAL
:final
